@@ -417,7 +417,6 @@ HyperLink(type, bp, header, eol)
      char *bp, **header, **eol;
 {
     char *sp, *head = *header;
-    int len;
 
     switch (type)
     {
@@ -570,7 +569,7 @@ char*
 ExtractNodeAndHyperize(buffer, header, body)
      char *buffer, **header, **body;
 {
-    char c, *sp, *bp = buffer, *node, *headerBuffer, *eol;
+    char *sp, *bp = buffer, *node, *headerBuffer, *eol;
     int type;
 
     while (*bp && *bp != INFO_COOKIE)
@@ -623,7 +622,7 @@ char*
 MakeNode(nodename, header, body)
      char *nodename, **header, **body;
 {
-    char *bp, *sp, *tp, *node;
+    char *bp, *sp;
     int i, p;
     String f = infofile;
 
@@ -723,7 +722,7 @@ PositionNode(node, highlight)
     Cardinal numChildren;
     int child;
     Position x, y, tx, ty;
-    Dimension w, h, pw, ph, tw, th;
+    Dimension w, h, pw, ph;
 
     XtVaGetValues(tree,
 		  XtNchildren, &children,
@@ -774,7 +773,6 @@ RevealNode(tag)
      char *tag;
 {
     String node, header, body;
-    int i;
 
     if (currentTag >= 0 && strcmp(tag, tagTable[currentTag].tag) == 0)
     {
@@ -838,7 +836,7 @@ DisplayNode(widget, client_data, call_data)
      Widget widget;
      XtPointer client_data, call_data;
 {
-    char *tag, *node;
+    char *tag;
 
     XtVaGetValues(widget, XtNlabel, &tag, NULL);
     tag = XtNewString(tag);
@@ -892,7 +890,7 @@ ProcessMenuItem(buffer, parent)
      Widget parent;
 {
     Widget node;
-    char *sp, *bp, *nodename, *help;
+    char *sp, *bp, *nodename;
     
     sp = bp = buffer;
     bp = Find(bp, ':');
@@ -1016,10 +1014,9 @@ ShowInfo(widget, event, params, num_params)
      Widget widget;
      XEvent *event;
      String *params;
-     Cardinal num_params;
+     Cardinal *num_params;
 {
     XPointer value;
-    String nodename;
 
     if(XFindContext(XtDisplay(widget),
 		    (XID) XrmStringToQuark(XtName(widget)),
@@ -1039,7 +1036,7 @@ ClearInfo(widget, event, params, num_params)
      Widget widget;
      XEvent *event;
      String *params;
-     Cardinal num_params;
+     Cardinal *num_params;
 {
     XtVaSetValues(InfoOf(widget), XtNlabel, "", NULL);
 }
@@ -1459,7 +1456,6 @@ SetHyperWMHints(shell)
 {
     Window window = XtWindow(shell);
     Display *display = XtDisplay(shell);
-    WidgetList children;
     Widget viewport = XtNameToWidget(shell, "*view");
     Dimension wHeight, vHeight;
     int margin;
@@ -1518,13 +1514,11 @@ MakeHyperWindow(nodename)
      char *nodename;
 {
     Widget popup, pane, view, hpane, quit, map, info;
-    char *node;
     Display *display = XtDisplay(top);
     Atom wm_delete_window;
     RowColRec rowsCols;
     XFontStruct *hyperFont, *normalFont;
-    Dimension width, height;
-    int rows, columns, margin, vSpace = 4;
+    int margin, vSpace = 4;
 
     popup = XtVaCreatePopupShell("hyperwin", topLevelShellWidgetClass, top,
 				 NULL);
@@ -1865,6 +1859,8 @@ main(argc, argv)
     Listen();
 
     XtAppMainLoop(app);
+
+    exit(0);
 }
 
 
